==> apache-servicecomb-java-chassis-distribution-3.1.1-src.zip: apache-servicecomb-java-chassis-distribution-3.1.1-src/transports/transport-rest/transport-rest-client/src/main/java/org/apache/servicecomb/transport/rest/client/TransportRestClientConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.transport.rest.client;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
public class TransportRestClientConfiguration {
  @Bean
  public RestClientSenderFilter restClientSenderFilter() {
    return new RestClientSenderFilter();
  }

  @Bean
  public RestClientCodecFilter restClientCodecFilter() {
    return new RestClientCodecFilter();
  }

  @Bean
  public RestClientDecoder restClientDecoder() {
    return new RestClientDecoder();
  }

  @Bean
  public RestClientTransportContextFactory restClientTransportContextFactory() {
    return new RestClientTransportContextFactory();
  }

  @Bean
  public RestClientEncoder restClientEncoder() {
    return new RestClientEncoder();
  }
}

==> apache-servicecomb-java-chassis-distribution-3.3.0-src.zip: apache-servicecomb-java-chassis-distribution-3.3.0-src/transports/transport-rest/transport-rest-client/src/main/java/org/apache/servicecomb/transport/rest/client/TransportRestClientConfiguration.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.servicecomb.transport.rest.client;

import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;

@Configuration
public class TransportRestClientConfiguration {
  @Bean
  public RestClientSenderFilter restClientSenderFilter() {
    return new RestClientSenderFilter();
  }

  @Bean
  public RestClientCodecFilter restClientCodecFilter() {
    return new RestClientCodecFilter();
  }

  @Bean
  public WebSocketClientCodecFilter webSocketClientCodecFilter() {
    return new WebSocketClientCodecFilter();
  }

  @Bean
  public RestClientDecoder restClientDecoder() {
    return new RestClientDecoder();
  }

  @Bean
  public RestClientTransportContextFactory restClientTransportContextFactory() {
    return new RestClientTransportContextFactory();
  }

  @Bean
  public RestClientEncoder restClientEncoder() {
    return new RestClientEncoder();
  }
}
